def set_window_position(driver: object, x: int, y: int) -> None:
    driver.set_window_position(x, y)  # type: ignore
